@@ -18,3 +18,15 @@ def plot_out(figsize=None, dpi=60, newline=True, print_out=True):
 
     pl.gcf().set_size_inches(old_size)
     pl.clf()
+
+img_count = 0
+def image_out(img, newline=True, print_out=True):
+    global img_count
+    filename = f"plot_{os.path.basename(sys.argv[0])}_{img_count:03d}.png"
+    img_count += 1
+    
+    img.save(filename)
+    if print_out:
+        print(f"<{filename}>{os.linesep if newline else ''}")
+
+    return filename
